==> qtjambi-debuginfo-macos-5.15.19.jar: sources/QtJambiCore/QStringMatcher_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qstringmatcher.h>
#include <QtCore/QVariant>
#include <QtCore/qnamespace.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QStringMatcher(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QStringMatcher")
    QStringMatcher *_ptr = reinterpret_cast<QStringMatcher *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QStringMatcher()
void __qt_construct_QStringMatcher(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QStringMatcher()")
    Q_UNUSED(__java_arguments)
    QStringMatcher *__qt_this = new(__qtjambi_ptr) QStringMatcher();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QStringMatcher::QStringMatcher()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QStringMatcher_initialize_1native__Lio_qt_core_QStringMatcher_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QStringMatcher::QStringMatcher()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QStringMatcher, sizeof(QStringMatcher), typeid(QStringMatcher), false, &deleter_QStringMatcher, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QStringMatcher(QString,Qt::CaseSensitivity)
void __qt_construct_QStringMatcher_cref_QString(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QStringMatcher(QString,Qt::CaseSensitivity)")
    jstring pattern0 = static_cast<jstring>(__java_arguments[0].l);
    QString  __qt_pattern0 = qtjambi_cast<QString>(__jni_env, pattern0);
    QStringMatcher *__qt_this = new(__qtjambi_ptr) QStringMatcher(__qt_pattern0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// new QStringMatcher(QString,Qt::CaseSensitivity)
void __qt_construct_QStringMatcher_cref_QString_Qt_CaseSensitivity(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QStringMatcher(QString,Qt::CaseSensitivity)")
    jstring pattern0 = static_cast<jstring>(__java_arguments[0].l);
    QString  __qt_pattern0 = qtjambi_cast<QString>(__jni_env, pattern0);
    jobject cs1 = __java_arguments[1].l;
    Qt::CaseSensitivity __qt_cs1 = qtjambi_cast<Qt::CaseSensitivity>(__jni_env, cs1);
    QStringMatcher *__qt_this = new(__qtjambi_ptr) QStringMatcher(__qt_pattern0, Qt::CaseSensitivity(__qt_cs1));
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QStringMatcher::QStringMatcher(QString,Qt::CaseSensitivity)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QStringMatcher_initialize_1native__Lio_qt_core_QStringMatcher_2Ljava_lang_String_2Lio_qt_core_Qt_00024CaseSensitivity_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jstring pattern0,
 jobject cs1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QStringMatcher::QStringMatcher(QString,Qt::CaseSensitivity)")
    QTJAMBI_TRY {
        jvalue arguments[2];
        arguments[0].l = pattern0;
        arguments[1].l = cs1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QStringMatcher_cref_QString_Qt_CaseSensitivity, sizeof(QStringMatcher), typeid(QStringMatcher), false, &deleter_QStringMatcher, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QStringMatcher(QStringMatcher)
void __qt_construct_QStringMatcher_cref_QStringMatcher(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QStringMatcher(QStringMatcher)")
    jobject other0 = __java_arguments[0].l;
    const QStringMatcher& __qt_other0 = qtjambi_cast<const QStringMatcher& >(__jni_env, other0);
    QStringMatcher *__qt_this = new(__qtjambi_ptr) QStringMatcher(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QStringMatcher::QStringMatcher(QStringMatcher)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QStringMatcher_initialize_1native__Lio_qt_core_QStringMatcher_2Lio_qt_core_QStringMatcher_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QStringMatcher::QStringMatcher(QStringMatcher)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QStringMatcher_cref_QStringMatcher, sizeof(QStringMatcher), typeid(QStringMatcher), false, &deleter_QStringMatcher, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QStringMatcher
void __qt_destruct_QStringMatcher(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QStringMatcher")
    reinterpret_cast<QStringMatcher*>(ptr)->~QStringMatcher();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QStringMatcher::caseSensitivity()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QStringMatcher_caseSensitivity_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QStringMatcher *__qt_this = QtJambiAPI::objectFromNativeId<QStringMatcher>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QStringMatcher::caseSensitivity()const", __qt_this)
        Qt::CaseSensitivity __qt_return_value = __qt_this->caseSensitivity();
        __java_return_value = __qt_return_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QStringMatcher::indexIn(QString,int)const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QStringMatcher_indexIn_1native_1cref_1QString_1int_1constfct__JLjava_lang_String_2I)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring str0,
 jint from1)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QStringMatcher *__qt_this = QtJambiAPI::objectFromNativeId<QStringMatcher>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QStringMatcher::indexIn(QString,int)const", __qt_this)
        QString  __qt_str0 = qtjambi_cast<QString>(__jni_env, str0);
        __java_return_value = __qt_this->indexIn(__qt_str0, static_cast<int>(from1));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QStringMatcher::pattern()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QStringMatcher_pattern_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QStringMatcher *__qt_this = QtJambiAPI::objectFromNativeId<QStringMatcher>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QStringMatcher::pattern()const", __qt_this)
        QString __qt_return_value = __qt_this->pattern();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QStringMatcher::setCaseSensitivity(Qt::CaseSensitivity)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QStringMatcher_setCaseSensitivity_1native_1Qt_1CaseSensitivity__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint cs0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QStringMatcher *__qt_this = QtJambiAPI::objectFromNativeId<QStringMatcher>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QStringMatcher::setCaseSensitivity(Qt::CaseSensitivity)", __qt_this)
        Qt::CaseSensitivity __qt_cs0 = qtjambi_cast<Qt::CaseSensitivity>(__jni_env, cs0);
        __qt_this->setCaseSensitivity(Qt::CaseSensitivity(__qt_cs0));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QStringMatcher::setPattern(QString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QStringMatcher_setPattern_1native_1cref_1QString__JLjava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring pattern0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QStringMatcher *__qt_this = QtJambiAPI::objectFromNativeId<QStringMatcher>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QStringMatcher::setPattern(QString)", __qt_this)
        QString  __qt_pattern0 = qtjambi_cast<QString>(__jni_env, pattern0);
        __qt_this->setPattern(__qt_pattern0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QStringMatcher_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QStringMatcher *__qt_this = QtJambiAPI::objectFromNativeId<QStringMatcher>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QStringMatcher(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QStringMatcher>("QStringMatcher", "io/qt/core/QStringMatcher");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QStringMatcher, {
        ConstructorInfo(&__qt_construct_QStringMatcher, nullptr)
       ,ConstructorInfo(&__qt_construct_QStringMatcher_cref_QString, "Ljava/lang/String;")
       ,ConstructorInfo(&__qt_construct_QStringMatcher_cref_QString_Qt_CaseSensitivity, "Ljava/lang/String;Lio/qt/core/Qt$CaseSensitivity;")
       ,ConstructorInfo(&__qt_construct_QStringMatcher_cref_QStringMatcher, "Lio/qt/core/QStringMatcher;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QStringMatcher);
    registerMetaType<QStringMatcher>("QStringMatcher");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-macos-6.7.2.jar: sources/QtJambiCore/QStringMatcher_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qstringmatcher.h>
#include <QtCore/QVariant>
#include <QtCore/qnamespace.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QStringMatcher(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QStringMatcher")
    QStringMatcher *_ptr = reinterpret_cast<QStringMatcher *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QStringMatcher()
void __qt_construct_QStringMatcher(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QStringMatcher()")
    Q_UNUSED(__java_arguments)
    QStringMatcher *__qt_this = new(__qtjambi_ptr) QStringMatcher();
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
}

// QStringMatcher::QStringMatcher()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QStringMatcher_initialize_1native__Lio_qt_core_QStringMatcher_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QStringMatcher::QStringMatcher()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QStringMatcher, sizeof(QStringMatcher), typeid(QStringMatcher), 0, false, &deleter_QStringMatcher, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QStringMatcher(QString,Qt::CaseSensitivity)
void __qt_construct_QStringMatcher_cref_QString(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QStringMatcher(QString,Qt::CaseSensitivity)")
    jstring pattern0 = static_cast<jstring>(__java_arguments[0].l);
    QString __qt_pattern0 = qtjambi_cast<QString>(__jni_env, pattern0);
    QStringMatcher *__qt_this = new(__qtjambi_ptr) QStringMatcher(__qt_pattern0);
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
}

// new QStringMatcher(QString,Qt::CaseSensitivity)
void __qt_construct_QStringMatcher_cref_QString_Qt_CaseSensitivity(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QStringMatcher(QString,Qt::CaseSensitivity)")
    jstring pattern0 = static_cast<jstring>(__java_arguments[0].l);
    QString __qt_pattern0 = qtjambi_cast<QString>(__jni_env, pattern0);
    jobject cs1 = __java_arguments[1].l;
    Qt::CaseSensitivity __qt_cs1 = qtjambi_cast<Qt::CaseSensitivity>(__jni_env, cs1);
    QStringMatcher *__qt_this = new(__qtjambi_ptr) QStringMatcher(__qt_pattern0, Qt::CaseSensitivity(__qt_cs1));
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
}

// QStringMatcher::QStringMatcher(QString,Qt::CaseSensitivity)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QStringMatcher_initialize_1native__Lio_qt_core_QStringMatcher_2Ljava_lang_String_2Lio_qt_core_Qt_00024CaseSensitivity_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jstring pattern0,
 jobject cs1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QStringMatcher::QStringMatcher(QString,Qt::CaseSensitivity)")
    QTJAMBI_TRY {
        jvalue arguments[2];
        arguments[0].l = pattern0;
        arguments[1].l = cs1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QStringMatcher_cref_QString_Qt_CaseSensitivity, sizeof(QStringMatcher), typeid(QStringMatcher), 0, false, &deleter_QStringMatcher, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QStringMatcher(QStringMatcher)
void __qt_construct_QStringMatcher_cref_QStringMatcher(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QStringMatcher(QStringMatcher)")
    jobject other0 = __java_arguments[0].l;
    const QStringMatcher& __qt_other0 = qtjambi_cast<const QStringMatcher&>(__jni_env, other0);
    QStringMatcher *__qt_this = new(__qtjambi_ptr) QStringMatcher(__qt_other0);
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
}

// QStringMatcher::QStringMatcher(QStringMatcher)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QStringMatcher_initialize_1native__Lio_qt_core_QStringMatcher_2Lio_qt_core_QStringMatcher_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QStringMatcher::QStringMatcher(QStringMatcher)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QStringMatcher_cref_QStringMatcher, sizeof(QStringMatcher), typeid(QStringMatcher), 0, false, &deleter_QStringMatcher, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QStringMatcher
void __qt_destruct_QStringMatcher(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QStringMatcher")
    reinterpret_cast<QStringMatcher*>(ptr)->~QStringMatcher();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QStringMatcher::caseSensitivity()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QStringMatcher_caseSensitivity_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QStringMatcher *__qt_this = QtJambiAPI::objectFromNativeId<QStringMatcher>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QStringMatcher::caseSensitivity()const", __this_nativeId)
        Qt::CaseSensitivity __qt_return_value = __qt_this->caseSensitivity();
        __java_return_value = __qt_return_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QStringMatcher::indexIn(QString,qsizetype)const
extern "C" Q_DECL_EXPORT jlong JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QStringMatcher_indexIn_1native_1cref_1QString_1qsizetype_1constfct__JLjava_lang_String_2J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring str0,
 jlong from1)
{
    Q_UNUSED(__this)
    jlong __java_return_value{0};
    QTJAMBI_TRY {
        const QStringMatcher *__qt_this = QtJambiAPI::objectFromNativeId<QStringMatcher>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QStringMatcher::indexIn(QString,qsizetype)const", __this_nativeId)
        QString __qt_str0 = qtjambi_cast<QString>(__jni_env, str0);
        qsizetype __qt_return_value = __qt_this->indexIn(__qt_str0, static_cast<qsizetype>(from1));
        __java_return_value = jlong(__qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QStringMatcher::pattern()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QStringMatcher_pattern_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QStringMatcher *__qt_this = QtJambiAPI::objectFromNativeId<QStringMatcher>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QStringMatcher::pattern()const", __this_nativeId)
        QString __qt_return_value = __qt_this->pattern();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QStringMatcher::patternView()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QStringMatcher_patternView_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QStringMatcher *__qt_this = QtJambiAPI::objectFromNativeId<QStringMatcher>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QStringMatcher::patternView()const", __this_nativeId)
        QStringView __qt_return_value = __qt_this->patternView();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QStringMatcher::setCaseSensitivity(Qt::CaseSensitivity)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QStringMatcher_setCaseSensitivity_1native_1Qt_1CaseSensitivity__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint cs0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QStringMatcher *__qt_this = QtJambiAPI::objectFromNativeId<QStringMatcher>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QStringMatcher::setCaseSensitivity(Qt::CaseSensitivity)", __this_nativeId)
        Qt::CaseSensitivity __qt_cs0 = qtjambi_cast<Qt::CaseSensitivity>(__jni_env, cs0);
        __qt_this->setCaseSensitivity(Qt::CaseSensitivity(__qt_cs0));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QStringMatcher::setPattern(QString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QStringMatcher_setPattern_1native_1cref_1QString__JLjava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring pattern0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QStringMatcher *__qt_this = QtJambiAPI::objectFromNativeId<QStringMatcher>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QStringMatcher::setPattern(QString)", __this_nativeId)
        QString __qt_pattern0 = qtjambi_cast<QString>(__jni_env, pattern0);
        __qt_this->setPattern(__qt_pattern0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QStringMatcher_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QStringMatcher *__qt_this = QtJambiAPI::objectFromNativeId<QStringMatcher>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QStringMatcher(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QStringMatcher>("QStringMatcher", "io/qt/core/QStringMatcher");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, 0, &__qt_destruct_QStringMatcher, {
        ConstructorInfo(&__qt_construct_QStringMatcher, nullptr)
       ,ConstructorInfo(&__qt_construct_QStringMatcher_cref_QString, "Ljava/lang/String;")
       ,ConstructorInfo(&__qt_construct_QStringMatcher_cref_QString_Qt_CaseSensitivity, "Ljava/lang/String;Lio/qt/core/Qt$CaseSensitivity;")
       ,ConstructorInfo(&__qt_construct_QStringMatcher_cref_QStringMatcher, "Lio/qt/core/QStringMatcher;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QStringMatcher);
    registerMetaType<QStringMatcher>("QStringMatcher");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
